/*
 * #%L
 * Pollen :: Services
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2012 CodeLutin, Tony Chemit
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.pollen.services;

import org.chorem.pollen.PollenTechnicalException;

import java.lang.reflect.InvocationTargetException;

/**
 * Factory of services.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.3
 */
public class PollenServiceFactory {

    public <E extends PollenService> E newService(Class<E> clazz, PollenServiceContext serviceContext) {
        // instantiate service using empty constructor
        E service;
        try {
            service = clazz.getConstructor().newInstance();
        } catch (InstantiationException e) {
            throw new PollenTechnicalException(e);
        } catch (IllegalAccessException e) {
            throw new PollenTechnicalException(e);
        } catch (InvocationTargetException e) {
            throw new PollenTechnicalException(e);
        } catch (NoSuchMethodException e) {
            throw new PollenTechnicalException(e);
        }

        service.setServiceContext(serviceContext);

        return service;
    }

}
